@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -30,7 +30,7 @@ G_BEGIN_DECLS
 
 void                 eds_module_initialize (GTypeModule *module);
 void                 eds_module_shutdown   (void);
-void                 eds_module_list_types (const GType **types, int *num_types);
+void                 eds_module_list_types (const GType **types, gint *num_types);
 
 G_END_DECLS
 
