@@ -368,9 +368,14 @@ exchange_mapi_cal_util_fetch_recipients (ECalComponent *comp, GSList **recip_lis
 		const gchar *str = NULL;
 		icalparameter *param;
 
+		str = icalproperty_get_attendee (att_prop);
+		if (!str || g_ascii_strcasecmp (str, org) == 0) {
+			att_prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
+			continue;
+		}
+
 		recipient = g_new0 (ExchangeMAPIRecipient, 1);
 
-		str = icalproperty_get_attendee (att_prop);
 		if (!g_ascii_strncasecmp (str, "mailto:", 7))
 			recipient->email_id = (str) + 7;
 		else
@@ -439,6 +444,7 @@ set_attachments_to_cal_component (ECalComponent *comp, GSList *attach_list, cons
 		ExchangeMAPIStream *stream;
 		gchar *attach_file_url, *filename;
 		const gchar *str, *attach;
+		GError *error = NULL;
 		guint len;
 		gint fd = -1;
 
@@ -452,8 +458,15 @@ set_attachments_to_cal_component (ECalComponent *comp, GSList *attach_list, cons
 		str = (const gchar *) exchange_mapi_util_find_SPropVal_array_propval(attach_item->lpProps, PR_ATTACH_LONG_FILENAME_UNICODE);
 		if (!(str && *str))
 			str = (const gchar *) exchange_mapi_util_find_SPropVal_array_propval(attach_item->lpProps, PR_ATTACH_FILENAME_UNICODE);
-		attach_file_url = g_strconcat (local_store_uri, G_DIR_SEPARATOR_S, uid, "-", str, NULL);
-		filename = g_filename_from_uri (attach_file_url, NULL, NULL);
+		filename = g_strconcat (local_store_uri, G_DIR_SEPARATOR_S, uid, "-", str, NULL);
+		attach_file_url = g_filename_to_uri (filename, NULL, &error);
+	
+		if (!attach_file_url) {
+			g_message ("Could not get attach_file_url %s \n", error->message);
+			g_clear_error (&error);
+			g_free (filename);
+			return;
+		}
 
 		fd = g_open (filename, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
 		if (fd == -1) {
@@ -1231,7 +1244,7 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 	struct icaltimetype dtstart, dtend, utc_dtstart, utc_dtend;
 	const icaltimezone *utc_zone;
 	const gchar *dtstart_tz_location, *dtend_tz_location, *text = NULL;
-	struct timeval t;
+	time_t tt;
 
 	g_return_val_if_fail (conn != NULL, FALSE);
 	g_return_val_if_fail (mem_ctx != NULL, FALSE);
@@ -1267,12 +1280,8 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 
 	#define set_datetime_value(hex, dtval) G_STMT_START {		\
 		struct FILETIME	filetime;				\
-		NTTIME		nttime;					\
 									\
-		nttime = timeval_to_nttime(dtval);				\
-									\
-		filetime.dwLowDateTime = (nttime << 32) >> 32;		\
-		filetime.dwHighDateTime = nttime >> 32;			\
+		exchange_mapi_util_time_t_to_filetime (dtval, &filetime); \
 									\
 		if (!exchange_mapi_utils_add_spropvalue (mem_ctx, values, n_values, hex, &filetime)) \
 			return FALSE;	\
@@ -1280,12 +1289,8 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 
 	#define set_named_datetime_value(named_id, dtval) G_STMT_START { \
 		struct FILETIME	filetime;				\
-		NTTIME		nttime;					\
 									\
-		nttime = timeval_to_nttime(dtval);				\
-									\
-		filetime.dwLowDateTime = (nttime << 32) >> 32;		\
-		filetime.dwHighDateTime = nttime >> 32;			\
+		exchange_mapi_util_time_t_to_filetime (dtval, &filetime); \
 									\
 		if (!exchange_mapi_utils_add_spropvalue_named_id (conn, fid, mem_ctx, values, n_values, named_id, &filetime)) \
 			return FALSE;	\
@@ -1385,13 +1390,11 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 		}
 	set_named_value (PidLidReminderSet, &b);
 	set_named_value (PidLidReminderDelta, &flag32);
-	t.tv_sec = icaltime_as_timet (utc_dtstart);
-	t.tv_usec = 0;
-	set_named_datetime_value (PidLidReminderTime, &t);
-	t.tv_sec = icaltime_as_timet (utc_dtstart) - (flag32 * SECS_IN_MINUTE);
-	t.tv_usec = 0;
+	tt = icaltime_as_timet (utc_dtstart);
+	set_named_datetime_value (PidLidReminderTime, tt);
+	tt = icaltime_as_timet (utc_dtstart) - (flag32 * SECS_IN_MINUTE);
 	/* ReminderNextTime: FIXME for recurrence */
-	set_named_datetime_value (PidLidReminderSignalTime, &t);
+	set_named_datetime_value (PidLidReminderSignalTime, tt);
 
 	/* Sensitivity, Private */
 	flag32 = olNormal;	/* default */
@@ -1404,15 +1407,13 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 	set_value (PR_SENSITIVITY, &flag32);
 	set_named_value (PidLidPrivate, &b);
 
-	t.tv_sec = icaltime_as_timet (utc_dtstart);
-	t.tv_usec = 0;
-	set_named_datetime_value (PidLidCommonStart, &t);
-	set_datetime_value (PR_START_DATE, &t);
+	tt = icaltime_as_timet (utc_dtstart);
+	set_named_datetime_value (PidLidCommonStart, tt);
+	set_datetime_value (PR_START_DATE, tt);
 
-	t.tv_sec = icaltime_as_timet (utc_dtend);
-	t.tv_usec = 0;
-	set_named_datetime_value (PidLidCommonEnd, &t);
-	set_datetime_value (PR_END_DATE, &t);
+	tt = icaltime_as_timet (utc_dtend);
+	set_named_datetime_value (PidLidCommonEnd, tt);
+	set_datetime_value (PR_END_DATE, tt);
 
 	b = 1;
 	set_value (PR_RESPONSE_REQUESTED, &b);
@@ -1459,11 +1460,10 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 		set_named_value (PidLidAutoFillLocation, &b);
 
 		/* Start */
-		t.tv_sec = icaltime_as_timet (utc_dtstart);
-		t.tv_usec = 0;
-		set_named_datetime_value (PidLidAppointmentStartWhole, &t);
+		tt = icaltime_as_timet (utc_dtstart);
+		set_named_datetime_value (PidLidAppointmentStartWhole, tt);
 		/* FIXME: for recurrence */
-		set_named_datetime_value (PidLidClipStart, &t);
+		set_named_datetime_value (PidLidClipStart, tt);
 
 		/* Start TZ */
 		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtstart_tz_location && *dtstart_tz_location) ? dtstart_tz_location : "UTC");
@@ -1473,11 +1473,10 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 		}
 
 		/* End */
-		t.tv_sec = icaltime_as_timet (utc_dtend);
-		t.tv_usec = 0;
-		set_named_datetime_value (PidLidAppointmentEndWhole, &t);
+		tt = icaltime_as_timet (utc_dtend);
+		set_named_datetime_value (PidLidAppointmentEndWhole, tt);
 		/* FIXME: for recurrence */
-		set_named_datetime_value (PidLidClipEnd, &t);
+		set_named_datetime_value (PidLidClipEnd, tt);
 
 		/* End TZ */
 		mapi_tzid = exchange_mapi_cal_tz_util_get_mapi_equivalent ((dtend_tz_location && *dtend_tz_location) ? dtend_tz_location : "UTC");
@@ -1718,25 +1717,22 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 			completed = icalproperty_get_completed (prop);
 
 			completed.hour = completed.minute = completed.second = 0; completed.is_date = completed.is_utc = 1;
-			t.tv_sec = icaltime_as_timet (completed);
-			t.tv_usec = 0;
-			set_named_datetime_value (PidLidTaskDateCompleted, &t);
+			tt = icaltime_as_timet (completed);
+			set_named_datetime_value (PidLidTaskDateCompleted, tt);
 		}
 
 		/* Start */
 		dtstart.hour = dtstart.minute = dtstart.second = 0; dtstart.is_date = dtstart.is_utc = 1;
-		t.tv_sec = icaltime_as_timet (dtstart);
-		t.tv_usec = 0;
+		tt = icaltime_as_timet (dtstart);
 		if (!icaltime_is_null_time (dtstart)) {
-			set_named_datetime_value (PidLidTaskStartDate, &t);
+			set_named_datetime_value (PidLidTaskStartDate, tt);
 		}
 
 		/* Due */
 		dtend.hour = dtend.minute = dtend.second = 0; dtend.is_date = dtend.is_utc = 1;
-		t.tv_sec = icaltime_as_timet (dtend);
-		t.tv_usec = 0;
+		tt = icaltime_as_timet (dtend);
 		if (!icaltime_is_null_time (dtend)) {
-			set_named_datetime_value (PidLidTaskDueDate, &t);
+			set_named_datetime_value (PidLidTaskDueDate, tt);
 		}
 
 		/* FIXME: Evolution does not support recurring tasks */
@@ -1936,13 +1932,13 @@ populate_freebusy_data (struct Binary_r *bin, uint32_t month, uint32_t year, GLi
 }
 
 gboolean
-exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, GList *users, time_t start, time_t end, GList **freebusy, GError **mapi_error)
+exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, const GList *users, time_t start, time_t end, GList **freebusy, GError **mapi_error)
 {
 	struct SRow		aRow;
 	enum MAPISTATUS		ms;
 	uint32_t		i;
 	mapi_object_t           obj_store;
-	GList *l;
+	const GList *l;
 
 	const uint32_t			*publish_start;
 	const struct LongArray_r	*busy_months;
@@ -1954,7 +1950,6 @@ exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, GList
 	uint32_t			year;
 	uint32_t			event_year;
 
-	gchar *name = NULL;
 	ECalComponent *comp;
 	ECalComponentAttendee attendee;
 	GSList *attendee_list = NULL;
@@ -2001,8 +1996,6 @@ exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, GList
 		icalcomponent_set_dtend (icalcomp, end_time);
 
 		memset (&attendee, 0, sizeof (ECalComponentAttendee));
-		if (name)
-			attendee.cn = name;
 		if (l->data)
 			attendee.value = l->data;
 
@@ -2014,8 +2007,6 @@ exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, GList
 
 		e_cal_component_set_attendee_list (comp, attendee_list);
 		g_slist_free (attendee_list);
-		g_free ((gchar *) name);
-		g_free ((gchar *) l->data);
 
 		if (busy_months && ((*(const uint32_t *) busy_months) != MAPI_E_NOT_FOUND) &&
 		    busy_events && ((*(const uint32_t *) busy_events) != MAPI_E_NOT_FOUND)) {
@@ -2043,7 +2034,7 @@ exchange_mapi_cal_utils_get_free_busy_data (ExchangeMapiConnection *conn, GList
 
 		e_cal_component_commit_sequence (comp);
 		*freebusy = g_list_append (*freebusy, e_cal_component_get_as_string (comp));
-//		g_object_unref (comp);
+		g_object_unref (comp);
 		MAPIFreeBuffer(aRow.lpProps);
 	}
 
